@@ -2,17 +2,13 @@ package Acme::PlayCode;
 
 use Moose;
 use PPI;
+use Path::Class ();
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.02';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 with 'MooseX::Object::Pluggable';
 
-has 'io' => (
-    is  => 'rw',
-    isa => 'Str|ScalarRef',
-);
-
 has 'tokens' => (
     is  => 'rw',
     isa => 'ArrayRef',
@@ -27,20 +23,33 @@ has 'output' => (
     default => sub { [] }
 );
 
-sub run {
-    my ( $self ) = @_;
+sub play {
+    my ( $self, $code, $opts ) = @_;
+    
+    my $file;
+    if ( $code !~ /\s/ and -e $code ) {
+        $file = Path::Class::File->new($code);
+        $code = $file->slurp();
+    }
     
     # clear to multi-run
     $self->output( [] );
     $self->token_flag( 0 );
     
-    my $doc    = PPI::Document->new( $self->io );
+    my $doc    = PPI::Document->new( \$code );
     $self->tokens( $doc->find('PPI::Token') );
 
     $self->do_with_tokens();
     
     my @output = @{ $self->output };
-    return join('', @output);
+    my $output = join('', @output);
+    if ( $opts->{rewrite_file} and $file ) {
+        my $fh = $file->openw();
+        print $fh $output;
+        $fh->close();
+        
+    }
+    return $output;
 }
 
 sub do_with_tokens {
@@ -76,15 +85,17 @@ Acme::PlayCode - Play code to win
 =head1 SYNOPSIS
 
     use Acme::PlayCode;
-
-    my $app = Acme::PlayCode->new( io => $filename );
-    # or
-    my $app = Acme::PlayCode->new( io => \$code );
+    
+    my $app = Acme::PlayCode;
     
     $app->load_plugin('DoubleToSingle');
     $app->load_plugin('ExchangeCondition');
     
-    my $code_played = $app->run;
+    my $played_code = $app->play( $code );
+    # or
+    my $played_code = $app->play( $filename );
+    # or
+    $app->play( $filename, { rewrite_file => 1 } ); # override $filename with played code
 
 =head1 ALPHA WARNING
 
@@ -97,6 +108,24 @@ It aims to change the code to be better (to be worse if you want).
 
 More description and API detais will come later.
 
+=head1 PLUGINS
+
+=over 4
+
+=item L<Acme::PlayCode::Plugin::DoubleToSingle>
+
+Play code with Single and Double
+
+=item L<Acme::PlayCode::Plugin::ExchangeCondition>
+
+Play code with exchanging condition
+
+=item L<Acme::PlayCode::Plugin::PrintComma>
+
+Play code with printing comma
+
+=back
+
 =head1 SEE ALSO
 
 L<Moose>, L<PPI>, L<MooseX::Object::Pluggable>
